﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Collections;
using System.Data.SqlServerCe;
using System.Data;
using System.Web.Security;
using System.IO;

namespace Vanny {
    public partial class Agenda : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpleat, idEmpresa;

        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            calendar1.FirstDayOfWeek = FirstDayOfWeek.Monday;
            calendar1.TitleFormat = TitleFormat.MonthYear;
            calendar1.TitleStyle.BackColor = System.Drawing.ColorTranslator.FromHtml("#5D7B9D");
            calendar1.TitleStyle.ForeColor = System.Drawing.Color.White;
            calendar1.TitleStyle.Font.Bold = true;
            calendar1.TitleStyle.Height = 40;

            calendar1.NextPrevFormat = NextPrevFormat.ShortMonth;
            calendar1.NextPrevStyle.ForeColor = System.Drawing.Color.White;

            calendar1.BorderStyle = BorderStyle.Solid;
            calendar1.BorderColor = System.Drawing.ColorTranslator.FromHtml("#dee2e6");

            calendar1.ShowGridLines = true;
            calendar1.ShowDayHeader = true;

            calendar1.DayStyle.HorizontalAlign = HorizontalAlign.Left;
            calendar1.DayStyle.VerticalAlign = VerticalAlign.Top;
            calendar1.DayStyle.Height = new Unit(60);
            calendar1.DayStyle.Width = new Unit(100);

            //calendar1.OtherMonthDayStyle.BackColor = System.Drawing.Color.WhiteSmoke;
            calendar1.OtherMonthDayStyle.ForeColor = System.Drawing.Color.Silver;

            calendar1.SelectedDate = DateTime.Now;
            calendar1.DayNameFormat = DayNameFormat.Full;

            calendar1.DayHeaderStyle.BackColor = System.Drawing.ColorTranslator.FromHtml("#6A8CB3");
            calendar1.DayHeaderStyle.ForeColor = System.Drawing.Color.White;

            calendar1.TodayDayStyle.BackColor = System.Drawing.Color.SkyBlue;
            calendar1.WeekendDayStyle.BackColor = System.Drawing.Color.WhiteSmoke;

            lblNohay.Visible = false;

            if (!IsPostBack) {
                ListaCitas(calendar1.SelectedDate.Date);
            }

            //Session.Add("UpdateCita", 0);

        }

        public void ListaCitas(DateTime date) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCites = new DataSet();
            dsCites.Tables.Add("Cites");

            con.Open();

            string query = "SELECT id, titol, descripcio, hora, CONVERT(nvarchar, data, 3) AS data FROM cita " +
            "WHERE idEmpresa = @empresa and data = @data ORDER BY data, hora asc";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.Parameters.AddWithValue("@data", date);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCites.Tables["Cites"]);

            con.Close();

            if (dsCites.Tables["Cites"].Rows.Count > 0) {
                gridCitas.DataSource = dsCites.Tables[0];
                gridCitas.DataBind();

                lblNohay.Visible = false;
                gridCitas.Visible = true;

            } else {
                gridCitas.Visible = false;
                lblNohay.Visible = true;
            }

        }

        protected void calendar1_SelectionChanged(object sender, EventArgs e) {

            DateTime date = calendar1.SelectedDate;
            inputFecha.Text = calendar1.SelectedDate.ToShortDateString();

            ListaCitas(date);
        }

        public void nuevaCita() {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);

            idEmpleat = list.idEmpleat;
            idEmpresa = list.idEmpresa;

            con.Open();

            //Insertar nueva cita
            string insert = "insert into cita (titol, descripcio, idEmpresa, idEmpleat, hora, data) " +
                            "VALUES(@nom, @desc, @empresa, @empleat, @hora, @data)";

            SqlCeCommand command = new SqlCeCommand(insert, con);

            command.Parameters.AddWithValue("@nom", inputNom.Text);

            if (inputDesc.Text != "") {
                command.Parameters.AddWithValue("@desc", inputDesc.Text);
            } else {
                command.Parameters.AddWithValue("@desc", DBNull.Value);
            }

            command.Parameters.AddWithValue("@data", inputFecha.Text);
            command.Parameters.AddWithValue("@hora", inputHora.Value);
            command.Parameters.AddWithValue("@empleat", idEmpleat);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            command.ExecuteNonQuery();

            con.Close();
        }

        protected void btnNuevaCita_Click(object sender, EventArgs e) {

            int idCita = 0;
            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            if (Convert.ToInt32(Session["UpdateCita"]) == 1) { // Si estem editant una cita

                idCita = Convert.ToInt32(Session["idCita"]);

                con.Open();

                string query = "select * from cita where idEmpresa = @empresa and id = @idCita";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.Parameters.AddWithValue("@idCita", idCita);

                SqlCeDataReader reader = command.ExecuteResultSet(ResultSetOptions.Scrollable);

                if (reader.HasRows) { // Si ya existe

                    // Actualizamos los datos
                    string update = "UPDATE cita SET titol = @nom, descripcio = @desc, hora = @hora, data = @data WHERE id = @idCita and idEmpresa = @empresa";
                    SqlCeCommand commnd = new SqlCeCommand(update, con);
                    commnd.Parameters.AddWithValue("@idCita", idCita);
                    commnd.Parameters.AddWithValue("@empresa", idEmpresa);

                    commnd.Parameters.AddWithValue("@nom", inputNom.Text);
                    commnd.Parameters.AddWithValue("@desc", inputDesc.Text);
                    commnd.Parameters.AddWithValue("@hora", inputHora.Value);
                    commnd.Parameters.AddWithValue("@data", inputFecha.Text);

                    commnd.ExecuteNonQuery();

                    con.Close();

                    // Volver a cargar citas
                    ListaCitas(Convert.ToDateTime(inputFecha.Text));

                    inputNom.Text = String.Empty;
                    inputDesc.Text = String.Empty;

                }

            } else { // Si no existe la creamos

                con.Close();

                nuevaCita();

                //con.Close();

                // Volver a cargar citas
                ListaCitas(Convert.ToDateTime(inputFecha.Text));

                inputNom.Text = String.Empty;
                inputDesc.Text = String.Empty;
            }

            Session.Add("UpdateCita", Convert.ToInt32(0));
        }

        protected void gridCitas_RowCommand(object sender, GridViewCommandEventArgs e) {

            int index = Convert.ToInt32(e.CommandArgument);
            Label Label = (Label)gridCitas.Rows[index].FindControl("lblIdCita");
            int idCita = Convert.ToInt32(Label.Text);

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            if (e.CommandName == "edit") { // Editar cita seleccionada

                con.Open();

                string query = "SELECT id, titol, descripcio, hora, CONVERT(nvarchar, data, 3) AS data FROM cita WHERE idEmpresa = @empresa and id = @idCita ORDER BY data, hora asc";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.Parameters.AddWithValue("@idCita", idCita);

                SqlCeDataReader reader = command.ExecuteResultSet(ResultSetOptions.Scrollable);

                // Rellenamos los datos en el formulario
                if (reader.HasRows) {
                    while (reader.Read()) {
                        Session.Add("idCita", reader.GetInt32(0));
                        Session.Add("UpdateCita", Convert.ToInt32(1));
                        inputNom.Text = reader.GetString(1);

                        if (!reader.IsDBNull(reader.GetOrdinal("descripcio"))) {
                            inputDesc.Text = reader.GetString(2);
                        } else {
                            inputDesc.Text = "";
                        }

                        inputHora.Value = reader.GetString(3);
                        inputFecha.Text = reader.GetString(4);

                        inputNom.Focus();
                    }
                }

                con.Close();

            } else if (e.CommandName == "delete") { // Eliminar cita seleccionada
                               
                con.Open();

                string query = "DELETE FROM cita WHERE id = @idCita and idEmpresa = @empresa";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@idCita", idCita);
                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.ExecuteNonQuery();

                con.Close();

                // Volver a cargar citas
                if (inputFecha.Text == "") {
                    ListaCitas(Convert.ToDateTime(DateTime.Now.ToShortDateString()));
                } else {
                    ListaCitas(Convert.ToDateTime(inputFecha.Text));
                }
            }

        }

        protected void gridCitas_RowDeleting(object sender, GridViewDeleteEventArgs e) {

        }

        protected void gridCitas_RowEditing(object sender, GridViewEditEventArgs e) {

            e.Cancel = true;
        }

        protected void btnImportar_ServerClick(object sender, EventArgs e) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCalendar = new DataSet();
            dsCalendar.Tables.Add("Calendar");

            string targetFolder = Environment.GetFolderPath(Environment.SpecialFolder.DesktopDirectory);

            string query = "select * from cita where idEmpresa = @empresa";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCalendar.Tables["Calendar"]);

            DataTableCSVFile(dsCalendar.Tables["Calendar"], "Calendar.csv", targetFolder);

            con.Close();

        }

        public void DataTableCSVFile(DataTable dt, string sfilename, string strFilePath) {
            StreamWriter sw = new StreamWriter(strFilePath + sfilename, false);
            int iColCount = dt.Columns.Count;

            try {
                // Escribint les columnes
                for (int i = 0; i < iColCount; i++) {
                    sw.Write(dt.Columns[i]);
                    if (i < iColCount - 1) {
                        sw.Write(";");
                    }
                }

                sw.Write(sw.NewLine);

                // Escribint les files
                foreach (DataRow dr in dt.Rows) {
                    for (int i = 0; i < iColCount; i++) {
                        if (!Convert.IsDBNull(dr[i])) {
                            sw.Write(dr[i].ToString());
                        }

                        if (i < iColCount - 1) {
                            sw.Write(";");
                        }
                    }
                    sw.Write(sw.NewLine);
                }
                sw.Close();

                HttpContext.Current.Response.Clear();
                HttpContext.Current.Response.ContentType = "application/csv";
                HttpContext.Current.Response.AddHeader("Content-Disposition", "attachment; filename=" + sfilename);
                HttpContext.Current.Response.WriteFile(strFilePath + sfilename);
                HttpContext.Current.Response.Flush();
                HttpContext.Current.Response.End();

            } catch (Exception ex) {

            }
        }

    }
}