﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.Security;
using System.IO;
using System.Data.SqlServerCe;
using System.Data;

namespace Vanny {
    public partial class Articles : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpresa;

        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            if (!IsPostBack) {
                listaProductos(string.Empty, 0, 0);
                divLabelError.Visible = false;
                listaProdProveer(0);
            }

            divLabelError.Visible = false;
        }

        public void listaProductos(string filtre, int pageId, int tipo) {

            string query = "";

            if (tipo == 0 || tipo == 1) { // Tots o per defecte al carregar la pàgina
                if (filtre != string.Empty) {
                    query = "select * from article where nom LIKE @filtre OR descripcio LIKE @filtre order by idArt ASC";
                } else {
                    query = "select * from article order by idArt ASC";
                }
            } else if (tipo == 2) { // Productes
                if (filtre != string.Empty) {
                    query = "select * from article where (nom LIKE @filtre OR descripcio LIKE @filtre) AND servei = 0 order by idArt ASC";
                } else {
                    query = "select * from article where servei = 0 order by idArt ASC";
                }
            } else if (tipo == 3) { // Serveis
                if (filtre != string.Empty) {
                    query = "select * from article where (nom LIKE @filtre OR descripcio LIKE @filtre) AND servei = 1 order by idArt ASC";
                } else {
                    query = "select * from article where servei = 1 order by idArt ASC";
                }
            }

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsProd = new DataSet();
            dsProd.Tables.Add("Productos");

            con.Open();

            //Cargar lista productos
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@filtre", "%" + filtre + "%");

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsProd.Tables["Productos"]);

            con.Close();

            gridProductos.DataSource = dsProd;
            gridProductos.DataMember = "Productos";
            gridProductos.PageIndex = pageId;
            gridProductos.DataBind();

        }

        protected void gridProductos_RowCommand(object sender, GridViewCommandEventArgs e) {

            lblError.Visible = false;
            divLabelError.Visible = false;

            int index = Convert.ToInt32(e.CommandArgument);
            Label Label = (Label)gridProductos.Rows[index].FindControl("lblIdArt");
            int idArt = Convert.ToInt32(Label.Text);

            if (e.CommandName == "edit") {

                Response.Redirect("EditarProducto.aspx?id=" + idArt);

            } else if (e.CommandName == "delete") { // Eliminar producto

                string userName = User.Identity.Name;
                var list = login.obtenerUsuario(userName);
                idEmpresa = list.idEmpresa;

                if (!list.admin) { // Miramos si es administrador

                    divLabelError.Visible = true;

                    lblError.Text = "Para eliminar productos debes ser administrador.";
                    lblError.Visible = true;

                } else {

                    con.Open();

                    string query = "DELETE FROM article WHERE idArt = @idArt and idEmpresa = @empresa";
                    SqlCeCommand command = new SqlCeCommand(query, con);
                    command.Parameters.AddWithValue("@idArt", idArt);
                    command.Parameters.AddWithValue("@empresa", idEmpresa);
                    command.ExecuteNonQuery();

                    con.Close();

                    // Volver a cargar productos
                    listaProductos(string.Empty, 0, Convert.ToInt32(ddMostrar.SelectedValue));
                }

            }

        }

        protected void gridProductos_RowDeleting(object sender, GridViewDeleteEventArgs e) {

        }

        protected void gridProductos_RowEditing(object sender, GridViewEditEventArgs e) {

        }

        protected void btnSearch_Click(object sender, EventArgs e) {

            listaProductos(inputSearch.Value, 0, Convert.ToInt32(ddMostrar.SelectedValue));

        }

        protected void btnImportar_ServerClick(object sender, EventArgs e) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCalendar = new DataSet();
            dsCalendar.Tables.Add("Productos");

            string targetFolder = Environment.GetFolderPath(Environment.SpecialFolder.DesktopDirectory);

            string query = "select * from article order by idArt ASC";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCalendar.Tables["Productos"]);

            Agenda agnda = new Agenda();
            agnda.DataTableCSVFile(dsCalendar.Tables["Productos"], "Productos.csv", targetFolder);

            con.Close();

        }

        protected void gridProductos_PageIndexChanging(object sender, GridViewPageEventArgs e) {

            listaProductos(string.Empty, e.NewPageIndex, Convert.ToInt32(ddMostrar.SelectedValue));

        }

        protected void btnNewProd_Click(object sender, EventArgs e) {

            Response.Redirect("NuevoProducto.aspx");

        }

        protected void ddMostrar_SelectedIndexChanged(object sender, EventArgs e) {
            listaProductos(string.Empty, 0, Convert.ToInt32(ddMostrar.SelectedValue));
        }

        public void listaProdProveer(int pageId) {

            string query = "select idArt, reffab, fabricant, nom, existencies, stockIdeal, (stockIdeal - existencies) as pedir from article where existencies < stockIdeal order by idArt ASC";

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsProd = new DataSet();
            dsProd.Tables.Add("Productos");

            con.Open();

            //Cargar lista productos a proveer
            SqlCeCommand command = new SqlCeCommand(query, con);
            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsProd.Tables["Productos"]);

            con.Close();

            gridProdProveer.DataSource = dsProd;
            gridProdProveer.DataMember = "Productos";
            gridProdProveer.PageIndex = pageId;
            gridProdProveer.DataBind();

        }

        protected void gridProdProveer_PageIndexChanging(object sender, GridViewPageEventArgs e) {

            listaProdProveer(e.NewPageIndex);

        }


    }
}