﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data.SqlServerCe;
using System.Data;
using System.Web.UI.HtmlControls;
using System.Web.Security;
using System.IO;

namespace Vanny {
    public partial class Clients : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpleat, idEmpresa;

        protected void Page_Load(object sender, EventArgs e) {
                        
            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            if (!IsPostBack) {
                listaClientes(string.Empty);
            }

        }

        public void listaClientes(string filtre) {

            string query;
            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsClientes = new DataSet();
            dsClientes.Tables.Add("Clientes");
           
            con.Open();

            if (filtre == string.Empty) {
                query = "select * from client where idEmpresa = @empresa and dataBaixa IS NULL and idCli != 1 order by idCli ASC";
            } else {
                query = "select * from client where idEmpresa = @empresa and nom LIKE @filtre and dataBaixa IS NULL and idCli !=1 order by idCli ASC";
            }

            //Cargar lista clientes actuales (dataBaja IS NULL)
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.Parameters.AddWithValue("@filtre", "%" + filtre + "%");

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsClientes.Tables["Clientes"]);

            con.Close();

            gridClientes.DataSource = dsClientes;
            gridClientes.DataMember = "Clientes";
            gridClientes.DataBind();

        }

        public void nuevoCliente() {

            con.Open();

            //Insert nuevo cliente
            string insert = "insert into client (nom, raoSocial, direccio, poblacio, provincia, nif, telefon, mobil, email, dataAlta, dataBaixa, observacions, idEmpleat, idEmpresa) " +
                            "VALUES(@nom, @raoSocial, @dir, @pob, @prov, @nif, @tel, @mbl, @email, @dataAlta, @dataBaixa, @observa, @empleat, @empresa)";
            
            SqlCeCommand command = new SqlCeCommand(insert, con);

            command.Parameters.AddWithValue("@nom", inputNom.Text);

            if (inputRaoSocial.Text != "") {
                command.Parameters.AddWithValue("@raoSocial", inputRaoSocial.Text);
            } else {
                command.Parameters.AddWithValue("@raoSocial", DBNull.Value);
            }

            if (inputDireccio.Text != "") {
                command.Parameters.AddWithValue("@dir", inputDireccio.Text);
            } else {
                command.Parameters.AddWithValue("@dir", DBNull.Value);
            }

            if (inputPoblacio.Text != "") {
                command.Parameters.AddWithValue("@pob", inputPoblacio.Text);
            } else {
                command.Parameters.AddWithValue("@pob", DBNull.Value);
            }

            if (inputProvincia.Text != "") {
                command.Parameters.AddWithValue("@prov", inputProvincia.Text);
            } else {
                command.Parameters.AddWithValue("@prov", DBNull.Value);
            }

            command.Parameters.AddWithValue("@nif", inputNIF.Text.ToUpper());

            if (inputTelefono.Text != "") {
                command.Parameters.AddWithValue("@tel", inputTelefono.Text);
            } else {
                command.Parameters.AddWithValue("@tel", DBNull.Value);
            }

            if (inputMvl.Text != "") {
                command.Parameters.AddWithValue("@mbl", inputMvl.Text);
            } else {
                command.Parameters.AddWithValue("@mbl", DBNull.Value);
            }

            if (inputEmail.Text != "") {
                command.Parameters.AddWithValue("@email", inputEmail.Text);
            } else {
                command.Parameters.AddWithValue("@email", DBNull.Value);
            }

            command.Parameters.AddWithValue("@dataAlta", DateTime.Now);
            command.Parameters.AddWithValue("@dataBaixa", DBNull.Value);

            if (inputObserva.Text != "") {
                command.Parameters.AddWithValue("@observa", inputObserva.Text);
            } else {
                command.Parameters.AddWithValue("@observa", DBNull.Value);
            }

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);

            idEmpleat = list.idEmpleat;
            idEmpresa = list.idEmpresa;

            command.Parameters.AddWithValue("@empleat", idEmpleat);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.ExecuteNonQuery();

            con.Close();

        }

        protected void btnAddCli_Click(object sender, EventArgs e) {

            try {

                nuevoCliente();

                inputDireccio.Text = String.Empty;
                inputEmail.Text = String.Empty;
                inputMvl.Text = String.Empty;
                inputNIF.Text = String.Empty;
                inputNom.Text = String.Empty;
                inputObserva.Text = String.Empty;
                inputPoblacio.Text = String.Empty;
                inputProvincia.Text = String.Empty;
                inputRaoSocial.Text = String.Empty;
                inputTelefono.Text = String.Empty;

                // Volver a cargar clientes
                listaClientes(string.Empty);

            } catch (Exception ex) {
                lblOK.Text = "No se ha podido crear el cliente. " + ex;
                lblOK.Visible = true;
            }

        }

        protected void gridClientes_RowCommand(object sender, GridViewCommandEventArgs e) {

            int index = Convert.ToInt32(e.CommandArgument);
            Label Label = (Label)gridClientes.Rows[index].FindControl("lblIdCli");
            int idClient = Convert.ToInt32(Label.Text);

            if (e.CommandName == "edit") {

                Response.Redirect("EditarCliente.aspx?id=" + idClient);

            } else if (e.CommandName == "delete") { // Dar de baja cliente seleccionado

                string userName = User.Identity.Name;
                var list = login.obtenerUsuario(userName);
                idEmpresa = list.idEmpresa;
    
                con.Open();

                string query = "UPDATE client SET dataBaixa = @baixa WHERE idCli = @idCli and idEmpresa = @empresa";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@idCli", idClient);
                command.Parameters.AddWithValue("@baixa", DateTime.Now);
                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.ExecuteNonQuery();

                con.Close();

                // Volver a cargar clientes
                listaClientes(string.Empty);
            }

        }

        protected void gridClientes_RowDeleting(object sender, GridViewDeleteEventArgs e) {

        }

        protected void gridClientes_RowEditing(object sender, GridViewEditEventArgs e) {

        }


        protected void btnSearch_Click(object sender, EventArgs e) {

            listaClientes(inputSearch.Value);

        }

        protected void btnImportar_ServerClick(object sender, EventArgs e) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCalendar = new DataSet();
            dsCalendar.Tables.Add("Clients");

            string targetFolder = Environment.GetFolderPath(Environment.SpecialFolder.DesktopDirectory);

            string query = "select * from client where idEmpresa = @empresa";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCalendar.Tables["Clients"]);

            Agenda agnda = new Agenda();
            agnda.DataTableCSVFile(dsCalendar.Tables["Clients"], "Clientes.csv", targetFolder);

            con.Close();

        }


    }
}