﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data.SqlServerCe;
using System.Data;
using System.Web.Security;

namespace Vanny {
    public partial class Deutes : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpleat, idEmpresa;

        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            if (!IsPostBack) {
                listaDeudas(0, string.Empty);
            }
        }

        protected void btnAddDeuda_Click(object sender, EventArgs e) {

            nuevaDeuda();

            inputNom.Text = String.Empty;
            inputDesc.Text = String.Empty;
            inputImporte.Text = String.Empty;

            // Volver a cargar lista deudas
            listaDeudas(0, inputSearch.Value);
        }

        public void listaDeudas(int tipo, string filtre) {

            string query = "";

            if (tipo == 0 || tipo == 1) { // Pendents de saldar o per defecte al carregar la pàgina
                if (filtre != string.Empty) {
                    query = "SELECT * FROM deute where idEmpresa = @empresa AND (nom LIKE @filtre OR descripcio LIKE @filtre) AND dataSaldat IS NULL ORDER BY id ASC";
                } else {
                    query = "SELECT * FROM deute where idEmpresa = @empresa AND dataSaldat IS NULL ORDER BY id ASC";
                }
            } else if (tipo == 2) { // Saldades
                if (filtre != string.Empty) {
                    query = "SELECT * FROM deute where idEmpresa = @empresa AND (nom LIKE @filtre OR descripcio LIKE @filtre) AND dataSaldat IS NOT NULL ORDER BY id ASC";
                } else {
                    query = "SELECT * FROM deute where idEmpresa = @empresa AND dataSaldat IS NOT NULL ORDER BY id ASC";
                }
            } else if (tipo == 3) { // Totes
                if (filtre != string.Empty) {
                    query = "SELECT * FROM deute where idEmpresa = @empresa AND (nom LIKE @filtre OR descripcio LIKE @filtre) ORDER BY id ASC";
                } else {
                    query = "SELECT * FROM deute where idEmpresa = @empresa ORDER BY id ASC";
                }
            }

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsDeudas = new DataSet();
            dsDeudas.Tables.Add("Deudas");

            con.Open();

            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.Parameters.AddWithValue("@filtre", "%" + filtre + "%");

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsDeudas.Tables["Deudas"]);

            con.Close();

            gridDeudas.DataSource = dsDeudas;
            gridDeudas.DataMember = "Deudas";
            gridDeudas.DataBind();

        }

        public void nuevaDeuda() {

            con.Open();

            //Insert nueva deuda
            string insert = "insert into deute (nom, descripcio, import, dataCreacio, dataSaldat, idEmpresa) " +
                            "VALUES(@nom, @desc, @import, @crea, @saldat, @empresa)";

            SqlCeCommand command = new SqlCeCommand(insert, con);

            command.Parameters.AddWithValue("@nom", inputNom.Text);
            command.Parameters.AddWithValue("@import", inputImporte.Text);
            command.Parameters.AddWithValue("@crea", DateTime.Now);
            command.Parameters.AddWithValue("@saldat", DBNull.Value);

            if (inputDesc.Text != "") {
                command.Parameters.AddWithValue("@desc", inputDesc.Text);
            } else {
                command.Parameters.AddWithValue("@desc", DBNull.Value);
            }

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);

            idEmpleat = list.idEmpleat;
            idEmpresa = list.idEmpresa;

            command.Parameters.AddWithValue("@empresa", idEmpresa);

            try {
                command.ExecuteNonQuery();

            } catch (Exception ex) {
                lblOK.Text = "No se ha podido crear la deuda. ";
                lblOK.Visible = true;
            }
            con.Close();

        }

        protected void ddMostrar_SelectedIndexChanged(object sender, EventArgs e) {
            listaDeudas(Convert.ToInt32(ddMostrar.SelectedValue), inputSearch.Value);
        }

        protected void gridDeudas_RowCommand(object sender, GridViewCommandEventArgs e) {

            int index = Convert.ToInt32(e.CommandArgument);
            Label Label = (Label)gridDeudas.Rows[index].FindControl("lblIdDeuda");
            int idDeuda = Convert.ToInt32(Label.Text);

            if (e.CommandName == "edit") {

                Response.Redirect("EditarDeuda.aspx?id=" + idDeuda);

            } else if (e.CommandName == "saldar") { // Dar de baja cliente seleccionado

                string userName = User.Identity.Name;
                var list = login.obtenerUsuario(userName);
                idEmpresa = list.idEmpresa;

                con.Open();

                string query = "UPDATE deute SET dataSaldat = @saldat WHERE id = @id and idEmpresa = @empresa";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@id", idDeuda);
                command.Parameters.AddWithValue("@saldat", DateTime.Now);
                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.ExecuteNonQuery();

                con.Close();

                // Volver a cargar deudas
                ddMostrar.SelectedValue = "2";
                listaDeudas(2, inputSearch.Value);
            }

        }

        protected void gridDeudas_RowDeleting(object sender, GridViewDeleteEventArgs e) {

        }

        protected void gridDeudas_RowEditing(object sender, GridViewEditEventArgs e) {

        }

        protected void btnSearchDeuda_Click(object sender, EventArgs e) {
            listaDeudas(Convert.ToInt32(ddMostrar.SelectedValue), inputSearch.Value);

        }

        protected void btnImportar_ServerClick(object sender, EventArgs e) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCalendar = new DataSet();
            dsCalendar.Tables.Add("Deutes");

            string targetFolder = Environment.GetFolderPath(Environment.SpecialFolder.DesktopDirectory);

            string query = "SELECT * FROM deute where idEmpresa = @empresa ORDER BY id ASC";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCalendar.Tables["Deutes"]);

            Agenda agnda = new Agenda();
            agnda.DataTableCSVFile(dsCalendar.Tables["Deutes"], "Deudas.csv", targetFolder);

            con.Close();

        }
    }
}