﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.Security;
using System.Data.SqlServerCe;
using System.Data;

namespace Vanny {
    public partial class Home : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpresa;

        DataTable prodVenta = new DataTable("Prod");

        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            lblNohay.Visible = false;
            lblError.Visible = false;
            divLabelError.Visible = false;
            divError.Visible = false;
            lblOK.Visible = false;

            if (!IsPostBack) {
                ListaCitas(DateTime.Now.Date);
                CargarClientes();
                CargarProducto();

                DataTable dtProd = gridProd.DataSource as DataTable;
                gridProd.DataSource = dtProd;
                gridProd.DataBind();
            }

        }

        public void ListaCitas(DateTime date) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCites = new DataSet();
            dsCites.Tables.Add("Cites");

            con.Open();

            string query = "select (hora+' '+titol+' - '+descripcio) AS Cita from cita where idEmpresa = @empresa and data = @data order by hora asc";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.Parameters.AddWithValue("@data", date);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCites.Tables["Cites"]);

            con.Close();

            SelectDay.Text = DateTime.Now.ToLongDateString();

            if (dsCites.Tables["Cites"].Rows.Count > 0) {

                repeater1.DataSource = dsCites.Tables[0];
                repeater1.DataBind();

                lblNohay.Visible = false;
                SelectDay.Visible = true;
                repeater1.Visible = true;

            } else {

                SelectDay.Visible = true;
                repeater1.Visible = false;

                lblNohay.Visible = true;
            }

        }

        public void CargarClientes() {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsClientes = new DataSet();

            con.Open();

            string query = "select * from client where idEmpresa = @empresa and dataBaixa IS NULL order by idCli asc";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsClientes);

            con.Close();

            ddCliente.DataSource = dsClientes.Tables[0];
            ddCliente.DataTextField = "nom";
            ddCliente.DataValueField = "idCli";
            ddCliente.DataBind();

            inputIdCli.Text = "1";

        }

        public void CargarProducto() {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsProducto = new DataSet();

            con.Open();

            string query = "select * from article where idEmpresa = @empresa order by idArt asc";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsProducto);

            con.Close();

            ddProducto.DataSource = dsProducto.Tables[0];
            ddProducto.DataTextField = "nom";
            ddProducto.DataValueField = "reffab";
            ddProducto.DataBind();

        }

        protected void inputIdCli_TextChanged(object sender, EventArgs e) {

        }

        protected void inputIdArt_TextChanged(object sender, EventArgs e) {

        }

        protected void ddCliente_SelectedIndexChanged(object sender, EventArgs e) {

            inputIdCli.Text = ddCliente.SelectedValue.ToString();
        }

        protected void ddProducto_SelectedIndexChanged(object sender, EventArgs e) {

            inputIdArt.Text = ddProducto.SelectedValue.ToString();
            inputCant.Text = string.Empty;
            inputCant.Focus();
        }

        protected void gridProd_RowCommand(object sender, GridViewCommandEventArgs e) {

            lblError.Visible = false;
            divLabelError.Visible = false;

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            int index = Convert.ToInt32(e.CommandArgument);
            Label Label = (Label)gridProd.Rows[index].FindControl("lblIdArt");
            int idArt = Convert.ToInt32(Label.Text);

            DataTable dtProd = ViewState["mydatasource"] as DataTable;

            if (e.CommandName == "edit") {

                //Response.Redirect("EditarProducto.aspx?id=" + idArt);

            } else if (e.CommandName == "delete") { // Eliminar producto

                try {

                    gridProd.DataSource = dtProd;
                    ViewState["mydatasource"] = dtProd;

                    dtProd.Rows.RemoveAt(index);

                    gridProd.DataSource = dtProd;
                    ViewState["mydatasource"] = dtProd;

                    gridProd.DataBind();

                } catch (Exception ex) {

                }

            }

            if (dtProd.Rows.Count != 0) {

                // Averiguar iva de empresa
                decimal iva = 0, total = 0, baseImp = 0;

                con.Open();

                string query = "select iva from empresa where idEmp = @empresa";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@empresa", idEmpresa);

                SqlCeResultSet results = command.ExecuteResultSet(ResultSetOptions.Scrollable);

                if (results.HasRows) {
                    results.ReadFirst();
                    iva = results.GetDecimal(0);
                }

                con.Close();

                // Calcular base, iva i total
                foreach (DataRow row in dtProd.Rows) {
                    baseImp += Convert.ToDecimal(Convert.ToDecimal(row["Importe"]) / (iva + 1));
                }

                foreach (DataColumn col in dtProd.Columns) {
                    total = Decimal.Parse(dtProd.Compute("Sum(Importe)", "").ToString());
                }

                lblBImp.Text = Math.Round(baseImp, 2).ToString() + " €";
                lblIva.Text = Math.Round(total - baseImp, 2).ToString() + " €";
                lblTotal.Text = total.ToString() + " €";

                lblBImp.Text = Math.Round(baseImp, 2).ToString() + " €";
                lblIva.Text = Math.Round(total - baseImp, 2).ToString() + " €";
                lblTotal.Text = Math.Round(total, 2).ToString() + " €";
            }

        }

        protected void gridProd_RowDeleting(object sender, GridViewDeleteEventArgs e) {

        }

        protected void gridProd_RowEditing(object sender, GridViewEditEventArgs e) {

        }

        public void iniciarTabla() {

            DataColumn column = new DataColumn();
            column.DataType = System.Type.GetType("System.Int32");
            column.ColumnName = "id";
            column.AutoIncrement = true;
            column.AutoIncrementSeed = 1;
            column.AutoIncrementStep = 1;
            prodVenta.Columns.Add(column);

            prodVenta.Columns.Add("Reffab", typeof(String));
            prodVenta.Columns.Add("Nombre", typeof(String));
            prodVenta.Columns.Add("Precio", typeof(Double));
            prodVenta.Columns.Add("Cantidad", typeof(Int32));
            prodVenta.Columns.Add("Importe", typeof(Double));
            prodVenta.Columns.Add("SubFam", typeof(Double));

        }

        protected void btnAdd_Click(object sender, EventArgs e) {

            // Coger datos artículo
            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;
            double importe;

            DataTable dtProd = ViewState["mydatasource"] as DataTable;

            if (inputCant.Text == string.Empty) {
                // S'ha d'especifica la quantitat
                divLabelError.Visible = true;
                lblError.Text = "Por favor, especifique la cantidad.";
                lblError.Visible = true;
                return;
            } 

            con.Open();
            string query = "select idArt, nom AS Nombre, preuVenda AS Precio, codSubFam, existencies, servei from article where idEmpresa = @empresa and reffab = @reffab";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.Parameters.AddWithValue("@reffab", inputIdArt.Text);

            SqlCeResultSet results = command.ExecuteResultSet(ResultSetOptions.Scrollable);

            if (results.HasRows) {

                results.ReadFirst();
                importe = results.GetDouble(2) * Convert.ToUInt32(inputCant.Text);

                if (results.GetBoolean(5)) { // Si es un servicio

                    if (dtProd == null) {

                        iniciarTabla();
                        prodVenta.Rows.Add(null, inputIdArt.Text, results.GetString(1), results.GetDouble(2), Convert.ToUInt32(inputCant.Text), importe, results.GetInt32(3).ToString());

                        gridProd.DataSource = prodVenta;
                        ViewState["mydatasource"] = prodVenta;
                        gridProd.DataBind();

                    } else {

                        dtProd.Rows.Add(null, inputIdArt.Text, results.GetString(1), results.GetDouble(2), Convert.ToUInt32(inputCant.Text), importe, results.GetInt32(3).ToString());
                        gridProd.DataSource = dtProd;
                        gridProd.DataBind();
                    }

                }  else if (results.GetInt32(4) >= Convert.ToInt32(inputCant.Text)) { // Si es un producto y tiene las existencias necesarias

                    if (dtProd == null) {

                        iniciarTabla();
                        prodVenta.Rows.Add(null, inputIdArt.Text, results.GetString(1), results.GetDouble(2), Convert.ToUInt32(inputCant.Text), importe, results.GetInt32(3).ToString());

                        gridProd.DataSource = prodVenta;
                        ViewState["mydatasource"] = prodVenta;
                        gridProd.DataBind();

                    } else {

                        dtProd.Rows.Add(null, inputIdArt.Text, results.GetString(1), results.GetDouble(2), Convert.ToUInt32(inputCant.Text), importe, results.GetInt32(3).ToString());
                        gridProd.DataSource = dtProd;
                        gridProd.DataBind();
                    }

                } else {
                    con.Close();
                    lblError.Text = "ERROR. Cantidad mayor que existencias de artículo.";
                    lblError.Visible = true;
                    divLabelError.Visible = true;
                }
                con.Close();

            } else {
                con.Close();
                lblError.Text = "La Referencia de fabricante no existe.";
                lblError.Visible = true;
                divLabelError.Visible = true;
            }


            // Averiguar iva de empresa
            decimal iva = 0, total = 0, baseImp = 0;

            con.Open();

            string query1 = "select iva from empresa where (idEmp = @empresa)";
            SqlCeCommand command1 = new SqlCeCommand(query1, con);
            command1.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeResultSet result = command1.ExecuteResultSet(ResultSetOptions.Scrollable);

            if (result.HasRows) {
                result.ReadFirst();
                iva = result.GetDecimal(0);
            }

            con.Close();

            // Calcular base, iva i total
            if (dtProd == null) {

                foreach (DataRow row in prodVenta.Rows) {
                    baseImp += Convert.ToDecimal(Convert.ToDecimal(row["Importe"]) / (iva + 1));
                }

                foreach (DataColumn col in prodVenta.Columns) {
                    total = Decimal.Parse(prodVenta.Compute("Sum(Importe)", "").ToString());
                }

                lblBImp.Text = Math.Round(baseImp, 2).ToString();
                lblIva.Text = Math.Round(total - baseImp, 2).ToString();
                lblTotal.Text = Math.Round(total, 2).ToString();

            } else {

                foreach (DataRow row in dtProd.Rows) {
                    baseImp += Convert.ToDecimal(Convert.ToDecimal(row["Importe"]) / (iva + 1));
                }

                foreach (DataColumn col in dtProd.Columns) {
                    total = Decimal.Parse(dtProd.Compute("Sum(Importe)", "").ToString());
                }

                lblBImp.Text = Math.Round(baseImp, 2).ToString();
                lblIva.Text = Math.Round(total - baseImp, 2).ToString();
                lblTotal.Text = Math.Round(total, 2).ToString();

            }


        }

        protected void inputTarjeta_TextChanged(object sender, EventArgs e) {

            decimal numTotal, numTotalPago;

            lblCambio.Text = "0.0";
            lblFalta.Text = "0.0";

            if (inputTarjeta.Text != string.Empty && inputContado.Text != string.Empty) {
                lblImpPago.Text = Math.Round((Convert.ToDecimal(inputTarjeta.Text) + Convert.ToDecimal(inputContado.Text)), 2).ToString();

            } else if (inputTarjeta.Text != string.Empty) {
                lblImpPago.Text = Math.Round(Convert.ToDecimal(inputTarjeta.Text), 2).ToString();

            } else if (inputContado.Text != string.Empty) {
                lblImpPago.Text = Math.Round(Convert.ToDecimal(inputContado.Text), 2).ToString();
            }


            if (Decimal.TryParse(lblTotal.Text.ToString(), out numTotal) == Decimal.TryParse(lblImpPago.Text.ToString(), out numTotalPago)) {

                if (numTotalPago > numTotal) {
                    lblCambio.Text = Math.Round(numTotalPago - numTotal, 2).ToString();

                } else if (numTotalPago < numTotal) {
                    lblFalta.Text = Math.Round(numTotal - numTotalPago, 2).ToString();

                } else {
                    lblCambio.Text = "0.0";
                    lblFalta.Text = "0.0";
                }
            }


        }

        protected void inputContado_TextChanged(object sender, EventArgs e) {

            decimal numTotal, numTotalPago;

            lblCambio.Text = "0.0";
            lblFalta.Text = "0.0";

            if (inputTarjeta.Text != string.Empty && inputContado.Text != string.Empty) {
                lblImpPago.Text = Math.Round((Convert.ToDecimal(inputTarjeta.Text.Replace('.', ',')) + Convert.ToDecimal(inputContado.Text.Replace('.', ','))), 2).ToString();

            } else if (inputTarjeta.Text != string.Empty) {
                lblImpPago.Text = Math.Round(Convert.ToDecimal(inputTarjeta.Text.Replace('.',',')), 2).ToString();

            } else if (inputContado.Text != string.Empty) {
                lblImpPago.Text = Math.Round(Convert.ToDecimal(inputContado.Text.Replace('.',',')), 2).ToString();
            }


            if (Decimal.TryParse(lblTotal.Text.ToString(), out numTotal) == Decimal.TryParse(lblImpPago.Text.ToString(), out numTotalPago)) {

                if (numTotalPago > numTotal) {
                    lblCambio.Text = Math.Round(Convert.ToDecimal(numTotalPago.ToString().Replace('.', ',')) - Convert.ToDecimal(numTotal.ToString().Replace('.', ',')), 2).ToString();

                } else if (numTotalPago < numTotal) {
                    lblFalta.Text = Math.Round(Convert.ToDecimal(numTotal.ToString().Replace('.', ',')) - Convert.ToDecimal(numTotalPago.ToString().Replace('.', ',')), 2).ToString();

                } else {
                    lblCambio.Text = "0.0";
                    lblFalta.Text = "0.0";
                }
            }

        }

        protected void btnGuardarVenta_Click(object sender, EventArgs e) {

            lblErrorFPago.Visible = false;
            divError.Visible = false;

            try {
                DataTable dtProd = ViewState["mydatasource"] as DataTable;
                string userName = User.Identity.Name;
                var list = login.obtenerUsuario(userName);

                con.Open();

                //Insertar venta
                string insert = "insert into venda (idClient, nom, data, base, iva, total, fpag1, fpag2, idEmpleat, idEmpresa) " +
                                "VALUES(@cli, @nom, @data, @base, @iva, @total, @fpag1, @fpag2, @empleat, @empresa)";

                SqlCeCommand command = new SqlCeCommand(insert, con);

                command.Parameters.AddWithValue("@cli", ddCliente.SelectedValue);
                command.Parameters.AddWithValue("@nom", ddCliente.SelectedItem.Text);
                command.Parameters.AddWithValue("@data", DateTime.Now);
                command.Parameters.AddWithValue("@base", Convert.ToDecimal(lblBImp.Text));
                command.Parameters.AddWithValue("@iva", Convert.ToDecimal(lblIva.Text));
                command.Parameters.AddWithValue("@total", Convert.ToDecimal(lblTotal.Text));
                command.Parameters.AddWithValue("@empleat", list.idEmpleat);
                command.Parameters.AddWithValue("@empresa", list.idEmpresa);

                if (inputContado.Text != "" || inputTarjeta.Text != "") {
                    if (inputContado.Text != "") {
                        command.Parameters.AddWithValue("@fpag1", Convert.ToDecimal(inputContado.Text.Replace('.', ',')));
                        if (inputTarjeta.Text != "") {
                            command.Parameters.AddWithValue("@fpag2", Convert.ToDecimal(inputTarjeta.Text.Replace('.', ',')));
                        } else {
                            command.Parameters.AddWithValue("@fpag2", Convert.ToDecimal(0));
                        }
                    } else if (inputTarjeta.Text != "") {
                        command.Parameters.AddWithValue("@fpag2", Convert.ToDecimal(inputTarjeta.Text.Replace('.', ',')));
                        if (inputContado.Text != "") {
                            command.Parameters.AddWithValue("@fpag1", Convert.ToDecimal(0));
                        } else {
                            command.Parameters.AddWithValue("@fpag1", Convert.ToDecimal(inputContado.Text.Replace('.', ',')));
                        }
                    } 
                } else {
                    // S'ha d'especifica una forma de pagament
                    divError.Visible = true;
                    lblErrorFPago.Text = "Por favor, especifique una forma de pago.";
                    lblErrorFPago.Visible = true;

                    return;
                }

                command.ExecuteNonQuery();


                // Esbrinar ultim ID insertat
                string query = "SELECT @@IDENTITY";
                SqlCeCommand cmnd = new SqlCeCommand(query, con);
                int id = Convert.ToInt32(cmnd.ExecuteScalar());


                //Insertar linies de venda
                foreach (DataRow row in dtProd.Rows) {

                    string insertLin = "insert into linVenda (numVenda, idArt, nom, pvp, quantitat, import, codSubFam) " +
                                    "VALUES(@id, @idArt, @nom, @pvp, @quant, @imp, @subfam)";

                    SqlCeCommand com = new SqlCeCommand(insertLin, con);

                    com.Parameters.AddWithValue("@id", id);
                    com.Parameters.AddWithValue("@idArt", row["Reffab"].ToString());
                    com.Parameters.AddWithValue("@nom", row["Nombre"].ToString());
                    com.Parameters.AddWithValue("@pvp", Convert.ToDecimal(row["Precio"].ToString()));
                    com.Parameters.AddWithValue("@quant", Convert.ToInt32(row["Cantidad"].ToString()));
                    com.Parameters.AddWithValue("@imp", Convert.ToDecimal(row["Importe"].ToString()));
                    com.Parameters.AddWithValue("@subfam", Convert.ToInt32(row["SubFam"].ToString()));

                    com.ExecuteNonQuery();

                    // Actualizar existencias
                    actualizarStock(row["Reffab"].ToString(), Convert.ToInt32(row["Cantidad"].ToString()));

                }

                con.Close();
                lblOK.Text = "La venta se ha guardado correctamente.";
                lblOK.CssClass = "alert alert-primary";
                lblOK.Visible = true;

                string currentPage = this.Page.Request.AppRelativeCurrentExecutionFilePath;
                Response.Redirect(currentPage);

            } catch (Exception ex) {
                lblOK.Text = "Error. No se ha podido guardar la venta.";
                lblOK.CssClass = "alert alert-danger";
                lblOK.Visible = true;
            }

        }

        public void actualizarStock(string reffab, int cant) {

            string update = "update article SET existencies = (existencies - @quant) where reffab = @reffab AND servei = 0";

            SqlCeCommand com = new SqlCeCommand(update, con);
            com.Parameters.AddWithValue("@reffab", reffab);
            com.Parameters.AddWithValue("@quant", cant);

            com.ExecuteNonQuery();

        }


    }
}