﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data.SqlServerCe;
using System.Web.Security;
using System.Data;

namespace Vanny {
    public partial class NuevoProducto : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpresa;


        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            if (!IsPostBack) {
                cargarFam();
                ddFam.SelectedIndex = 11;
                ddSubFam.SelectedIndex = 23;
            }
        }

        public void listaProductos(string filtre, int pageId) {

            string query;
            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsProd = new DataSet();
            dsProd.Tables.Add("Productos");

            con.Open();

            if (filtre == string.Empty) {
                query = "select * from article order by idArt ASC";
            } else {
                query = "select * from article where nom LIKE @filtre OR descripcio LIKE @filtre order by idCli ASC";
            }

            //Cargar lista clientes actuales (dataBaja IS NULL)
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@filtre", "%" + filtre + "%");

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsProd.Tables["Productos"]);

            con.Close();

        }

        public void nuevoProducto() {

            Boolean exist = false;

            con.Open();

            //Revisamos que el reffab no exista
            string query = "select * from article where reffab = @reffab";
            SqlCeCommand cmd = new SqlCeCommand(query, con);
            cmd.Parameters.AddWithValue("@reffab", inputRefFab.Text);

            SqlCeResultSet results = cmd.ExecuteResultSet(ResultSetOptions.Scrollable);

            if (results.HasRows) {  //Si existe mostraremos error
                exist = true;
            } else { //Si no existe lo crearemos
                exist = false;
            }

            con.Close();

            if (!exist) {

                con.Open();

                //Insert nuevo articulo
                string insert = "insert into article (nom, descripcio, existencies, preuVenda, fabricant, dataAlta, servei, reffab, codSubFam, idEmpresa, stockIdeal) " +
                                "VALUES(@nom, @desc, @stock, @pvp, @fab, @alta, @servei, @reffab, @subfam, @empresa, @stockIdeal)";

                SqlCeCommand command = new SqlCeCommand(insert, con);

                command.Parameters.AddWithValue("@nom", inputNom.Text);

                if (inputDesc.Text != "") {
                    command.Parameters.AddWithValue("@desc", inputDesc.Text);
                } else {
                    command.Parameters.AddWithValue("@desc", DBNull.Value);
                }

                if (inputStock.Text != "") {
                    command.Parameters.AddWithValue("@stock", Convert.ToInt32(inputStock.Text));
                } else {
                    command.Parameters.AddWithValue("@stock", DBNull.Value);
                }

                if (inputStockIdeal.Text != "") {
                    command.Parameters.AddWithValue("@stockIdeal", Convert.ToInt32(inputStockIdeal.Text));
                } else {
                    command.Parameters.AddWithValue("@stockIdeal", DBNull.Value);
                }

                command.Parameters.AddWithValue("@pvp", Math.Round(Convert.ToDecimal(inputPVP.Text),2));
                command.Parameters.AddWithValue("@fab", inputFab.Text);
                command.Parameters.AddWithValue("@alta", DateTime.Now);
                command.Parameters.AddWithValue("@reffab", inputRefFab.Text);
                command.Parameters.AddWithValue("@servei", Convert.ToBoolean(ddTipo.SelectedValue));
                command.Parameters.AddWithValue("@subfam", Convert.ToInt32(ddSubFam.SelectedValue));

                string userName = User.Identity.Name;
                var list = login.obtenerUsuario(userName);
                idEmpresa = list.idEmpresa;

                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.ExecuteNonQuery();

                con.Close();

            } else {
                lblOK.Text = "Error. La referencia de fabricante ya existe."; ;
                lblOK.Visible = true;
            }

        }

        public void cargarFam() {

            DataSet dsFam = new DataSet();
            string query = "select * from familia order by id ASC";

            con.Open();

            //Cargar families
            SqlCeCommand command = new SqlCeCommand(query, con);
            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsFam);

            con.Close();

            ddFam.DataSource = dsFam;
            ddFam.DataTextField = "nom";
            ddFam.DataValueField = "codFam";

            ddFam.SelectedIndex = 11;
            ddSubFam.SelectedIndex = 23;

            ddFam.DataBind();

        }

        protected void ddFam_SelectedIndexChanged(object sender, EventArgs e) {

            DataSet dsSubFam = new DataSet();

            string query = "select * from subfamilia WHERE codFam = @codFam order by id ASC";

            con.Open();

            //Cargar subfamilies
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@codFam", Convert.ToInt32(ddFam.SelectedValue));

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsSubFam);

            con.Close();

            ddSubFam.DataSource = dsSubFam;
            ddSubFam.DataTextField = "nom";
            ddSubFam.DataValueField = "codSubFam";
            ddSubFam.DataBind();

        }

        protected void btnAddProd_Click(object sender, EventArgs e) {

            lblOK.Visible = false;

            try {

                nuevoProducto();

                inputNom.Text = String.Empty;
                inputFab.Text = String.Empty;
                inputRefFab.Text = String.Empty;
                inputDesc.Text = String.Empty;
                inputStock.Text = String.Empty;
                inputStockIdeal.Text = String.Empty;
                inputPVP.Text = String.Empty;

                // Carregar productes
                listaProductos(string.Empty, 0);

            } catch (Exception ex) {
                lblOK.Text = "Error. No se ha podido crear el producto."; ;
                lblOK.Visible = true;
            }

        }
    }
}