﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data.SqlServerCe;
using System.Data;
using System.Web.Security;

namespace Vanny {
    public partial class Proveidors : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpresa;

        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            if (!IsPostBack) {
                listaProve();
            }
        }

        public void listaProve() {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsProve = new DataSet();
            dsProve.Tables.Add("Prove");

            con.Open();

            //Cargar lista proveedores actuales
            string query = "select * from proveidor where idEmpresa = @empresa order by idProve ASC";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsProve.Tables["Prove"]);

            con.Close();

            gridProve.DataSource = dsProve;
            gridProve.DataMember = "Prove";
            gridProve.DataBind();

        }

        public void nuevoProve() {

            con.Open();

            //Insert nuevo proveedor
            string insert = "insert into proveidor (nom, raoSocial, direccio, poblacio, provincia, telefon, mobil, email, contacte, idEmpresa) " +
                            "VALUES(@nom, @raoSocial, @dir, @pob, @provincia, @tel, @mbl, @email, @contact, @empresa)";

            SqlCeCommand command = new SqlCeCommand(insert, con);

            command.Parameters.AddWithValue("@nom", inputNom.Text);

            if (inputRaoSocial.Text != "") {
                command.Parameters.AddWithValue("@raoSocial", inputRaoSocial.Text);
            } else {
                command.Parameters.AddWithValue("@raoSocial", DBNull.Value);
            }

            if (inputDireccio.Text != "") {
                command.Parameters.AddWithValue("@dir", inputDireccio.Text);
            } else {
                command.Parameters.AddWithValue("@dir", DBNull.Value);
            }

            if (inputPoblacio.Text != "") {
                command.Parameters.AddWithValue("@pob", inputPoblacio.Text);
            } else {
                command.Parameters.AddWithValue("@pob", DBNull.Value);
            }

            if (inputProvincia.Text != "") {
                command.Parameters.AddWithValue("@provincia", inputProvincia.Text);
            } else {
                command.Parameters.AddWithValue("@provincia", inputProvincia.Text);
            }

            if (inputTelefono.Text != "") {
                command.Parameters.AddWithValue("@tel", inputTelefono.Text);
            } else {
                command.Parameters.AddWithValue("@tel", DBNull.Value);
            }

            if (inputMvl.Text != "") {
                command.Parameters.AddWithValue("@mbl", inputMvl.Text);
            } else {
                command.Parameters.AddWithValue("@mbl", DBNull.Value);
            }

            if (inputEmail.Text != "") {
                command.Parameters.AddWithValue("@email", inputEmail.Text);
            } else {
                command.Parameters.AddWithValue("@email", DBNull.Value);
            }

            if (inputContact.Text != "") {
                command.Parameters.AddWithValue("@contact", inputContact.Text);
            } else {
                command.Parameters.AddWithValue("@contact", DBNull.Value);
            }


            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);

            idEmpresa = list.idEmpresa;

            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.ExecuteNonQuery();

            con.Close();

        }

        protected void btnAddProve_Click(object sender, EventArgs e) {

            try {

                nuevoProve();

                inputDireccio.Text = String.Empty;
                inputEmail.Text = String.Empty;
                inputMvl.Text = String.Empty;
                inputContact.Text = String.Empty;
                inputNom.Text = String.Empty;
                inputPoblacio.Text = String.Empty;
                inputProvincia.Text = String.Empty;
                inputRaoSocial.Text = String.Empty;
                inputTelefono.Text = String.Empty;

                // Volver a cargar proveedores
                listaProve();

            } catch (Exception ex) {
                lblOK.Text = "No se ha podido crear el proveedor. " + ex;
                lblOK.Visible = true;
            }

        }

        protected void gridProve_RowCommand(object sender, GridViewCommandEventArgs e) {

            int index = Convert.ToInt32(e.CommandArgument);
            Label Label = (Label)gridProve.Rows[index].FindControl("lblIdProve");
            int idProveidor = Convert.ToInt32(Label.Text);

            if (e.CommandName == "edit") {

                Response.Redirect("EditarProveedor.aspx?id=" + idProveidor);

            } else if (e.CommandName == "delete") { // Eliminar proveedor seleccionado

                string userName = User.Identity.Name;
                var list = login.obtenerUsuario(userName);
                idEmpresa = list.idEmpresa;

                con.Open();

                string query = "DELETE proveidor WHERE idProve = @idProve and idEmpresa = @empresa";
                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@idProve", idProveidor);
                command.Parameters.AddWithValue("@empresa", idEmpresa);
                command.ExecuteNonQuery();

                con.Close();

                // Volver a cargar proveedores
                listaProve();
            }

        }

        protected void gridProve_RowDeleting(object sender, GridViewDeleteEventArgs e) {

        }

        protected void gridProve_RowEditing(object sender, GridViewEditEventArgs e) {

        }

        protected void btnImportar_ServerClick(object sender, EventArgs e) {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsCalendar = new DataSet();
            dsCalendar.Tables.Add("Prove");

            string targetFolder = Environment.GetFolderPath(Environment.SpecialFolder.DesktopDirectory);

            string query = "select * from proveidor where idEmpresa = @empresa order by idProve ASC";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsCalendar.Tables["Prove"]);

            Agenda agnda = new Agenda();
            agnda.DataTableCSVFile(dsCalendar.Tables["Prove"], "Proveedores.csv", targetFolder);

            con.Close();

        }

    }
}