﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.Security;
using System.Data.SqlServerCe;
using System.Data;

namespace Vanny {
    public partial class Vendes : System.Web.UI.Page {

        // Local
        public SqlCeConnection con = new SqlCeConnection(@"Data source= " + AppDomain.CurrentDomain.BaseDirectory + "App_Data\\vanny.sdf");
        Login login = new Login();
        int idEmpresa;

        protected void Page_Load(object sender, EventArgs e) {

            //Primero verificamos si el usuario está autenticado usando la propiedad IsAuthenticated. 
            //Si el usuario se autentica, se le redirige directamente a la página de inicio, que se configura como DefaultUrl 
            //en la configuración de autenticación de formularios del archivo Web.Config.

            if (!this.Page.User.Identity.IsAuthenticated) {
                FormsAuthentication.RedirectToLoginPage();
            }

            if (!IsPostBack) {

                CargarClientes();
                CargarProducto();

                DateTime fini = new DateTime(DateTime.Now.Year, DateTime.Now.Month, 1);
                DateTime ffin = fini.AddMonths(1).AddDays(-1);

                tbFIni.Text = fini.ToShortDateString();
                tbFFin.Text = ffin.ToShortDateString();

                CargarGrid(string.Empty, 0);

            }

        }

        public void CargarClientes() {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsClientes = new DataSet();

            con.Open();

            string query = "select * from client where idEmpresa = @empresa order by idCli asc";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsClientes);

            con.Close();

            ddCliente.DataSource = dsClientes.Tables[0];
            ddCliente.DataTextField = "nom";
            ddCliente.DataValueField = "idCli";
            ddCliente.DataBind();

            //inputIdCli.Text = "1";

        }

        public void CargarProducto() {

            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet dsProducto = new DataSet();

            con.Open();

            string query = "select * from article where idEmpresa = @empresa order by idArt asc";
            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(dsProducto);

            con.Close();

            ddProducto.DataSource = dsProducto.Tables[0];
            ddProducto.DataTextField = "nom";
            ddProducto.DataValueField = "reffab";
            ddProducto.DataBind();

        }

        public void CargarGrid(string filtres, int pageId) {

            string query;
            string userName = User.Identity.Name;
            var list = login.obtenerUsuario(userName);
            idEmpresa = list.idEmpresa;

            DataSet ds = new DataSet();
            ds.Tables.Add("Vendes");

            con.Open();

            if (filtres != string.Empty) {
                query = "select DISTINCT venda.numVenda, venda.idClient, venda.nom, venda.idEmpleat, venda.data, venda.base, venda.iva, venda.total, venda.fpag1, venda.fpag2, venda.idEmpresa "+
                        " from venda RIGHT OUTER JOIN linVenda ON venda.numVenda = linVenda.numVenda WHERE idEmpresa = @empresa and data BETWEEN @fini and @ffin " + filtres;
            } else {
                query = "selecT DISTINCT venda.numVenda, venda.idClient, venda.nom, venda.idEmpleat, venda.data, venda.base, venda.iva, venda.total, venda.fpag1, venda.fpag2, venda.idEmpresa "+
                        "from venda RIGHT OUTER JOIN linVenda ON venda.numVenda = linVenda.numVenda WHERE idEmpresa = @empresa and data BETWEEN @fini and @ffin";
            }

            SqlCeCommand command = new SqlCeCommand(query, con);
            command.Parameters.AddWithValue("@empresa", idEmpresa);
            command.Parameters.AddWithValue("@fini", Convert.ToDateTime(tbFIni.Text));
            command.Parameters.AddWithValue("@ffin", Convert.ToDateTime(tbFFin.Text));

            SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
            adapter.Fill(ds.Tables["Vendes"]);

            con.Close();

            gvVendes.DataSource = ds;
            gvVendes.DataMember = "Vendes";
            gvVendes.PageIndex = pageId;
            gvVendes.DataBind();

        }

        protected void ddCliente_SelectedIndexChanged(object sender, EventArgs e) {

            inputIdCli.Text = ddCliente.SelectedValue.ToString();
        }

        protected void ddProducto_SelectedIndexChanged(object sender, EventArgs e) {

            inputIdArt.Text = ddProducto.SelectedValue.ToString();
        }

        protected void btnFiltrar_Click(object sender, EventArgs e) {

            string filtres;
            Boolean cli = false;

            if (inputIdCli.Text != "") {
                filtres = "AND idClient = " + Convert.ToInt32(inputIdCli.Text);
                cli = true;
            } else {
                filtres = "";
                cli = false;
            }
            
            if (inputIdArt.Text != "") {
                if (!cli) {
                    filtres = " AND (linVenda.idArt = '" + inputIdArt.Text + "')";
                } else {
                    filtres += " AND (linVenda.idArt = '" + inputIdArt.Text + "')";
                }
            }

            CargarGrid(filtres, 0);

        }

        protected void btnImportar_ServerClick(object sender, EventArgs e) {

        }

        protected void inputIdCli_TextChanged(object sender, EventArgs e) {

        }

        protected void inputIdArt_TextChanged(object sender, EventArgs e) {

        }

        protected void gvVendes_OnRowDataBound(object sender, GridViewRowEventArgs e) {

            if (e.Row.RowType == DataControlRowType.DataRow) {

                Label lblID = (Label)e.Row.FindControl("lblId");
                string id = lblID.Text;

                GridView gvLinVendes = (GridView)e.Row.FindControl("gvLinVendes");
                DataSet ds = new DataSet();

                con.Open();

                string query = "select * from linVenda where numVenda = @id";

                SqlCeCommand command = new SqlCeCommand(query, con);
                command.Parameters.AddWithValue("@id", id);

                SqlCeDataAdapter adapter = new SqlCeDataAdapter(command);
                adapter.Fill(ds);

                con.Close();

                gvLinVendes.DataSource = ds;
                gvLinVendes.DataBind();

            }

        }

        protected void gvVendes_PageIndexChanging(object sender, GridViewPageEventArgs e) {

            CargarGrid(string.Empty, e.NewPageIndex);
        }

    }

}